<?php

namespace Drupal\migrate_source_graphql\Event;

use Drupal\migrate\Event\EventBase;
use Drupal\migrate\MigrateMessageInterface;
use Drupal\migrate\Plugin\MigrationInterface;

/**
 * Provides an event for manipulation the result set.
 */
class ResultsEvent extends EventBase {

  /**
   * The results.
   *
   * @var array
   */
  protected array $results;

  /**
   * Constructs a new ResultsEvent object.
   *
   * @param \Drupal\migrate\Plugin\MigrationInterface $migration
   *   The migration being run.
   * @param \Drupal\migrate\MigrateMessageInterface $message
   *   The Migrate message service.
   * @param array $results
   *   The results.
   */
  public function __construct(MigrationInterface $migration, MigrateMessageInterface $message, array $results) {
    parent::__construct($migration, $message);
    $this->results = $results;
  }

  /**
   * Returns the results.
   *
   * @return array
   *   The results.
   */
  public function getResults(): array {
    return $this->results;
  }

  /**
   * Sets the results.
   *
   * @param array $results
   *   The results.
   */
  public function setResults(array $results): void {
    $this->results = $results;
  }

}
