<?php

namespace Drupal\Tests\migrate_source_csv\Kernel\Plugin\migrate\source;

use Drupal\node\Entity\Node;
use Drupal\Tests\migrate\Kernel\MigrateTestBase;

class GraphQLTest extends MigrateTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'system',
    'field',
    'user',
    'node',
    'datetime',
    'migrate',
    'migrate_source_graphql',
    'migrate_source_graphql_test',
  ];

  /**
   * Tests execution of a BASIC migration sourced from GraphQLZero.
   */
  public function testMigrate(): void {
    $this->installEntitySchema('user');
    $this->installEntitySchema('node');
    $this->installConfig(['migrate_source_graphql_test']);

    /** @var \Drupal\migrate\Plugin\MigrationPluginManagerInterface $migrationManager */
    $migrationManager = $this->container->get('plugin.manager.migration');
    $migration = $migrationManager->createInstance('migrate_graphql_test');
    $this->executeMigration($migration);
    $node = Node::load(1);
    $this->assertEquals($node->label(), 'sunt aut facere repellat provident occaecati excepturi optio reprehenderit');
  }

  /**
   * Tests execution of a FILTERED migration sourced from GraphQLZero.
   */
  public function testMigrateWithFilters(): void {
    $this->installEntitySchema('user');
    $this->installEntitySchema('node');
    $this->installConfig(['migrate_source_graphql_test']);

    /** @var \Drupal\migrate\Plugin\MigrationPluginManagerInterface $migrationManager */
    $migrationManager = $this->container->get('plugin.manager.migration');

    // First test basic graphql migration "migrate_graphql_test".
    $migration = $migrationManager->createInstance('migrate_graphql_test_filters');
    $this->executeMigration($migration);
    $node = Node::load(1);
    $this->assertEquals($node->label(), 'sit asperiores ipsam eveniet odio non quia');
  }

  /**
   * Tests execution of a FILTERED migration sourced from GraphQLZero using data_key configuration property.
   */
  public function testMigrateWithFiltersAndDataKey(): void {
    $this->installEntitySchema('user');
    $this->installEntitySchema('node');
    $this->installConfig(['migrate_source_graphql_test']);

    /** @var \Drupal\migrate\Plugin\MigrationPluginManagerInterface $migrationManager */
    $migrationManager = $this->container->get('plugin.manager.migration');

    // First test basic graphql migration "migrate_graphql_test".
    $migration = $migrationManager->createInstance('migrate_graphql_test_datakey');
    $this->executeMigration($migration);
    $node = Node::load(1);
    $this->assertEquals($node->get('field_name')->value, 'Mrs. Dennis Schulist');
    $this->assertEquals($node->get('field_email')->value, 'Karley_Dach@jasper.info');
  }


}
